"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useIsCollapsed = exports.useItemHighlightContext = exports.useItemContext = exports.itemContext = void 0;
const react_1 = require("react");
const treeToRenderAdapter_1 = require("./treeToRenderAdapter");
const initialState = {
    renderData: [],
    hoveredItems: [],
    collapsedItemIds: [],
};
const store = react_1.createContext({
    state: {
        renderData: [[]],
        hoveredItems: [],
        collapsedItemIds: [],
    },
    dispatch: () => { },
});
exports.itemContext = store;
const useItemContext = (tree) => {
    const { newResult: renderDataRaw } = treeToRenderAdapter_1.generateRenderTree(tree);
    const [, ...renderMatrix] = renderDataRaw;
    const [state, dispatch] = react_1.useReducer((previousState, action) => {
        var _a, _b;
        switch (action.type) {
            case 'TOGGLE_COLLAPSE': {
                const { currentItem } = (_a = action.payload) !== null && _a !== void 0 ? _a : {};
                const isAlreadyCollapsed = previousState.collapsedItemIds.includes(currentItem.uniqueId);
                const newCollapsedItems = isAlreadyCollapsed
                    ? previousState.collapsedItemIds.filter(itemId => itemId !== currentItem.uniqueId)
                    : [...previousState.collapsedItemIds, currentItem.uniqueId];
                const { newResult: newRenderDataRaw } = treeToRenderAdapter_1.generateRenderTree(tree, newCollapsedItems);
                const [, ...newRenderData] = newRenderDataRaw;
                return Object.assign(Object.assign({}, previousState), { collapsedItemIds: newCollapsedItems, renderData: newRenderData });
            }
            case 'SET_HOVERED': {
                const { currentHoveredItem, hoveredColumnIndex: columnIndex, } = (_b = action.payload) !== null && _b !== void 0 ? _b : {};
                const path = currentHoveredItem
                    ? findPathFromItem([currentHoveredItem.id], currentHoveredItem.parentId, previousState.renderData.slice(0, Math.max(columnIndex, 0)))
                    : [];
                return Object.assign(Object.assign({}, previousState), { hoveredItems: path });
            }
            case 'SET_BLURRED': {
                return Object.assign(Object.assign({}, previousState), { hoveredItems: [] });
            }
            case 'UPDATE_TREE': {
                const { newResult: renderDataRawUpdated } = treeToRenderAdapter_1.generateRenderTree(tree, previousState.collapsedItemIds);
                const [, ...renderMatrixUpdated] = renderDataRawUpdated;
                console.log(Object.assign(Object.assign({}, previousState), { renderData: renderMatrixUpdated }));
                return Object.assign(Object.assign({}, previousState), { renderData: renderMatrixUpdated });
            }
            default:
                return Object.assign(Object.assign({}, previousState), { renderData: renderMatrix });
        }
    }, Object.assign(Object.assign({}, initialState), { renderData: renderMatrix }));
    react_1.useEffect(() => {
        dispatch({ type: 'UPDATE_TREE', payload: tree });
    }, [tree]);
    return [state, dispatch];
};
exports.useItemContext = useItemContext;
const useItemHighlightContext = ({ currentItem, }) => {
    const { state: { hoveredItems }, } = react_1.useContext(exports.itemContext);
    const highlighted = hoveredItems.some(itemId => itemId === currentItem.id);
    return highlighted;
};
exports.useItemHighlightContext = useItemHighlightContext;
const useIsCollapsed = ({ currentItem, }) => {
    const { state: { collapsedItemIds }, } = react_1.useContext(exports.itemContext);
    const isCollapsed = collapsedItemIds.some(collapsedItemId => collapsedItemId === currentItem.uniqueId);
    return isCollapsed;
};
exports.useIsCollapsed = useIsCollapsed;
function findPathFromItem(result = [], parentId, renderMatrix) {
    if (renderMatrix.length === 0) {
        return result;
    }
    if (renderMatrix.length === 1) {
        return [parentId, ...result];
    }
    const currentParentItem = renderMatrix[renderMatrix.length - 1].find(parent => parent.id === parentId);
    const newRenderMatrix = renderMatrix.slice(0, -1);
    return findPathFromItem([currentParentItem.id, ...result], currentParentItem.parentId, newRenderMatrix);
}
//# sourceMappingURL=item-context.js.map